**Example 1: xx**

xx

Input: 

```
tccli dsgc DescribeDSPAAssessmentPendingRiskOverview --cli-unfold-argument  \
    --DspaId abc \
    --TemplateId 0
```

Output: 
```
{
    "Response": {
        "PendingRiskCount": 0,
        "AffectedAssetCount": 0,
        "WeekRatio": 0,
        "RequestId": "abc"
    }
}
```

